@@ -28,7 +28,6 @@
 #include "panel-config-global.h"
 #include "panel-shell.h"
 #include "session.h"
-#include "status.h"
 #include "xstuff.h"
 
 extern int config_sync_timeout;
@@ -51,6 +50,8 @@ char *kde_menudir = NULL;
 char *kde_icondir = NULL;
 char *kde_mini_icondir = NULL;
 
+GnomeIconLoader *panel_icon_loader = NULL;
+
 static gchar *profile_name;
 
 static gboolean
@@ -153,7 +154,6 @@ kill_free_drawers (void)
 		PanelData *pd = li->data;
 		if (DRAWER_IS_WIDGET (pd->panel) &&
 		    PANEL_WIDGET (BASEP_WIDGET (pd->panel)->panel)->master_widget == NULL) {
-			status_unparent (pd->panel);
 			to_destroy = g_slist_prepend (to_destroy, pd->panel);
 		}
 	}
@@ -164,6 +164,7 @@ kill_free_drawers (void)
 
 static const struct poptOption options[] = {
   {"profile", '\0', POPT_ARG_STRING, &profile_name, 0, N_("Specify a profile name to load"), NULL},
+  POPT_AUTOHELP
   {NULL, '\0', 0, NULL, 0}
 };
 
@@ -175,11 +176,6 @@ main(int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	/*
-	 * Let applets spew.
-	 */
-	putenv ("BONOBO_ACTIVATION_DEBUG_OUTPUT=1");
-
 	gnome_program_init ("gnome-panel", VERSION,
 			    LIBGNOMEUI_MODULE,
 			    argc, argv,
@@ -193,6 +189,9 @@ main(int argc, char **argv)
 	
 	if (!panel_shell_register ())
 		return -1;
+
+	panel_icon_loader = gnome_icon_loader_new ();
+	
 	find_kde_directory();
 
 	client = gnome_master_client ();
@@ -215,8 +214,6 @@ main(int argc, char **argv)
 	panel_gconf_add_dir ("/desktop/gnome/interface");
 	panel_gconf_notify_add ("/apps/panel/global", panel_global_config_notify, NULL);
 
-	status_applet_create_offscreen ();
-
 	session_load ();	
 
 	kill_free_drawers ();
