@@ -26,6 +26,7 @@
 #define __PANEL_APPLET_H__
 
 #include <glib/gmacros.h>
+#include <gtk/gtkenums.h>
 #include <gtk/gtkeventbox.h>
 #include <libgnomeui/gnome-ui-init.h>
 #include <bonobo/bonobo-control.h>
@@ -61,6 +62,7 @@ typedef enum {
 	PANEL_APPLET_FLAGS_NONE   = 0,
 	PANEL_APPLET_EXPAND_MAJOR = 1 << 0,
 	PANEL_APPLET_EXPAND_MINOR = 1 << 1,
+	PANEL_APPLET_HAS_HANDLE   = 1 << 2,
 } PanelAppletFlags;
 
 typedef struct _PanelApplet        PanelApplet;
@@ -90,6 +92,8 @@ struct _PanelAppletClass {
 				   PanelAppletBackgroundType  type,
 				   GdkColor                  *color,
 				   GdkPixmap                 *pixmap);
+	void (*move_focus_out_of_applet) (PanelApplet        *frame,
+					  GtkDirectionType    direction);
 };
 
 GType              panel_applet_get_type             (void) G_GNUC_CONST;
@@ -116,6 +120,11 @@ PanelAppletFlags   panel_applet_get_flags            (PanelApplet      *applet);
 void      	   panel_applet_set_flags            (PanelApplet      *applet,
 						      PanelAppletFlags  flags);
 
+void      	   panel_applet_set_size_hints       (PanelApplet      *applet,
+						      const int        *size_hints,
+						      int               n_elements,
+						      int               base_size);
+
 BonoboControl     *panel_applet_get_control          (PanelApplet  *applet);
 BonoboUIComponent *panel_applet_get_popup_component  (PanelApplet  *applet);
 
